import { APIRoute } from "astro";
import { getPlanetById } from "../../../../lib/db/planets";
import { ObjectId } from "mongodb";
import Planet from "../../../../types/Planet";
import { calculateCurrentAvailableResources } from "../../../../lib/utils/resourceManager";

export const GET: APIRoute = async ({ params, request }) => {
    const planetId = params['planetId'];
    if(!planetId) return new Response(
        JSON.stringify({
            code: 400,
            message: "Bad Request"
        }), { status: 400 }
    );

    let planet: Planet | null;

    try {
        planet = await getPlanetById(new ObjectId(planetId));
        if(!planet) return new Response(
            JSON.stringify({
                code: 404,
                message: "Not Found"
            }), { status: 404 }
        );
    } catch(e) {
        return new Response(
            JSON.stringify({
                code: 500,
                message: "Internal Server Error"
            }), { status: 500 }
        );
    }

    await calculateCurrentAvailableResources(planet._id);

    return new Response(
        JSON.stringify({
            code: 200,
            message: "OK",
            data: JSON.parse(JSON.stringify(planet).replace(/_id/g, 'id'))
        })
    )
}